@@ -17,7 +17,7 @@ comment on column dbversion.description is 'Release description';
 
 -- latest schema version
 insert into dbversion(version, release, description)
-      values(138, now(), 'Work In Progress');
+      values(146, now(), 'Work In Progress');
 
 -- a SHA1 checksum
 create domain sha1 as bytea check (length(value) = 20);
@@ -76,12 +76,10 @@ comment on column content.object_id is 'Content identifier';
 create table origin
 (
   id       bigserial not null,
-  type     text, -- TODO use an enum here (?)
   url      text not null
 );
 
 comment on column origin.id is 'Artifact origin id';
-comment on column origin.type is 'Type of origin';
 comment on column origin.url is 'URL of origin';
 
 
@@ -119,31 +117,6 @@ comment on column skipped_content.origin is 'Origin table identifier';
 comment on column skipped_content.object_id is 'Skipped content identifier';
 
 
--- Log of all origin fetches (i.e., origin crawling) that have been done in the
--- past, or are still ongoing. Similar to list_history, but for origins.
-create table fetch_history
-(
-  id        bigserial,
-  origin    bigint,
-  date      timestamptz not null,
-  status    boolean,  -- true if and only if the fetch has been successful
-  result    jsonb,     -- more detailed returned values, times, etc...
-  stdout    text,
-  stderr    text,     -- null when status is true, filled otherwise
-  duration  interval  -- fetch duration of NULL if still ongoing
-);
-
-comment on table fetch_history is 'Log of all origin fetches';
-comment on column fetch_history.id is 'Identifier for fetch history';
-comment on column fetch_history.origin is 'Origin table identifier';
-comment on column fetch_history.date is 'Fetch start time';
-comment on column fetch_history.status is 'True indicates successful fetch';
-comment on column fetch_history.result is 'Detailed return values, times etc';
-comment on column fetch_history.stdout is 'Standard output of fetch operation';
-comment on column fetch_history.stderr is 'Standard error of fetch operation';
-comment on column fetch_history.duration is 'Time taken to complete fetch, NULL if ongoing';
-
-
 -- A file-system directory.  A directory is a list of directory entries (see
 -- tables: directory_entry_{dir,file}).
 --
@@ -176,9 +149,9 @@ comment on column directory.object_id is 'Short object identifier';
 create table directory_entry_dir
 (
   id      bigserial,
-  target  sha1_git,   -- id of target directory
-  name    unix_path,  -- path name, relative to containing dir
-  perms   file_perms  -- unix-like permissions
+  target  sha1_git not null,   -- id of target directory
+  name    unix_path not null,  -- path name, relative to containing dir
+  perms   file_perms not null  -- unix-like permissions
 );
 
 comment on table directory_entry_dir is 'Directory entry for directory';
@@ -192,9 +165,9 @@ comment on column directory_entry_dir.perms is 'Unix-like permissions';
 create table directory_entry_file
 (
   id      bigserial,
-  target  sha1_git,   -- id of target file
-  name    unix_path,  -- path name, relative to containing dir
-  perms   file_perms  -- unix-like permissions
+  target  sha1_git not null,   -- id of target file
+  name    unix_path not null,  -- path name, relative to containing dir
+  perms   file_perms not null  -- unix-like permissions
 );
 
 comment on table directory_entry_file is 'Directory entry for file';
@@ -208,9 +181,9 @@ comment on column directory_entry_file.perms is 'Unix-like permissions';
 create table directory_entry_rev
 (
   id      bigserial,
-  target  sha1_git,   -- id of target revision
-  name    unix_path,  -- path name, relative to containing dir
-  perms   file_perms  -- unix-like permissions
+  target  sha1_git not null,   -- id of target revision
+  name    unix_path not null,  -- path name, relative to containing dir
+  perms   file_perms not null  -- unix-like permissions
 );
 
 comment on table directory_entry_rev is 'Directory entry for revision';
@@ -266,7 +239,7 @@ create table revision
   committer_date_neg_utc_offset boolean
 );
 
-comment on table revision is 'Revision represents the state of a source code tree at a 
+comment on table revision is 'Revision represents the state of a source code tree at a
  specific point in time';
 comment on column revision.id is 'Git id of sha1 checksum';
 comment on column revision.date is 'Timestamp when revision was authored';
@@ -493,4 +466,3 @@ comment on column object_counts_bucketed.bucket_start is 'Lower bound (inclusive
 comment on column object_counts_bucketed.bucket_end is 'Upper bound (exclusive) for the bucket';
 comment on column object_counts_bucketed.value is 'Count of objects in the bucket';
 comment on column object_counts_bucketed.last_update is 'Last update for the object count in this bucket';
-
