@@ -16,6 +16,7 @@ alter table origin add primary key using index origin_pkey;
 
 create index concurrently on origin using gin (url gin_trgm_ops);
 create index concurrently on origin using hash (url);
+create index concurrently on origin using btree(digest(url, 'sha1'));
 
 
 -- skipped_content
@@ -31,14 +32,6 @@ create unique index concurrently on skipped_content(object_id);
 alter table skipped_content add constraint skipped_content_origin_fkey foreign key (origin) references origin(id) not valid;
 alter table skipped_content validate constraint skipped_content_origin_fkey;
 
--- fetch_history
-
-create unique index concurrently fetch_history_pkey on fetch_history(id);
-alter table fetch_history add primary key using index fetch_history_pkey;
-
-alter table fetch_history add constraint fetch_history_origin_fkey foreign key (origin) references origin(id) not valid;
-alter table fetch_history validate constraint fetch_history_origin_fkey;
-
 -- directory
 
 create unique index concurrently directory_pkey on directory(id);
@@ -132,6 +125,7 @@ create unique index concurrently origin_visit_pkey on origin_visit(origin, visit
 alter table origin_visit add primary key using index origin_visit_pkey;
 
 create index concurrently on origin_visit(date);
+create index concurrently on origin_visit(type, status, date);
 
 alter table origin_visit add constraint origin_visit_origin_fkey foreign key (origin) references origin(id) not valid;
 alter table origin_visit validate constraint origin_visit_origin_fkey;
@@ -146,6 +140,10 @@ create unique index concurrently on release(object_id);
 alter table release add constraint release_author_fkey foreign key (author) references person(id) not valid;
 alter table release validate constraint release_author_fkey;
 
+-- if the author is null, then the date must be null
+alter table release add constraint release_author_date_check check ((date is null) or (author is not null)) not valid;
+alter table release validate constraint release_author_date_check;
+
 -- tool
 create unique index tool_pkey on tool(id);
 alter table tool add primary key using index tool_pkey;
