@@ -6,8 +6,7 @@
 from hypothesis import given
 
 from swh.model.identifiers import snapshot_identifier, identifier_to_bytes
-from swh.model.hypothesis_strategies import \
-    snapshots, branch_names, branch_targets
+from swh.model.hypothesis_strategies import snapshots, branch_names, branch_targets
 
 from swh.storage.algos.snapshot import snapshot_get_all_branches
 from swh.storage.tests.test_in_memory import swh_storage_backend_config  # noqa
@@ -18,26 +17,20 @@ def test_snapshot_small(swh_storage, snapshot):  # noqa
     snapshot = snapshot.to_dict()
     swh_storage.snapshot_add([snapshot])
 
-    returned_snapshot = snapshot_get_all_branches(
-        swh_storage, snapshot['id'])
+    returned_snapshot = snapshot_get_all_branches(swh_storage, snapshot["id"])
     assert snapshot == returned_snapshot
 
 
-@given(branch_name=branch_names(),
-       branch_target=branch_targets(only_objects=True))
+@given(branch_name=branch_names(), branch_target=branch_targets(only_objects=True))
 def test_snapshot_large(swh_storage, branch_name, branch_target):  # noqa
     branch_target = branch_target.to_dict()
 
     snapshot = {
-        'branches': {
-            b'%s%05d' % (branch_name, i): branch_target
-            for i in range(10000)
-        }
+        "branches": {b"%s%05d" % (branch_name, i): branch_target for i in range(10000)}
     }
-    snapshot['id'] = identifier_to_bytes(snapshot_identifier(snapshot))
+    snapshot["id"] = identifier_to_bytes(snapshot_identifier(snapshot))
 
     swh_storage.snapshot_add([snapshot])
 
-    returned_snapshot = snapshot_get_all_branches(
-        swh_storage, snapshot['id'])
+    returned_snapshot = snapshot_get_all_branches(swh_storage, snapshot["id"])
     assert snapshot == returned_snapshot
