@@ -10,7 +10,7 @@ import pytest
 import swh.storage.api.server as server
 import swh.storage.storage
 from swh.storage import get_storage
-from swh.storage.tests.test_storage import TestStorageGeneratedData # noqa
+from swh.storage.tests.test_storage import TestStorageGeneratedData  # noqa
 from swh.storage.tests.test_storage import TestStorage as _TestStorage
 
 # tests are executed using imported classes (TestStorage and
@@ -21,10 +21,8 @@ from swh.storage.tests.test_storage import TestStorage as _TestStorage
 @pytest.fixture
 def app_server():
     storage_config = {
-        'cls': 'memory',
-        'journal_writer': {
-            'cls': 'memory',
-        },
+        "cls": "memory",
+        "journal_writer": {"cls": "memory",},
     }
     server.storage = swh.storage.get_storage(**storage_config)
     yield server
@@ -38,13 +36,7 @@ def app(app_server):
 @pytest.fixture
 def swh_rpc_client_class():
     def storage_factory(**kwargs):
-        storage_config = {
-            'cls': 'validate',
-            'storage': {
-                'cls': 'remote',
-                **kwargs,
-            }
-        }
+        storage_config = {"cls": "validate", "storage": {"cls": "remote", **kwargs,}}
         return get_storage(**storage_config)
 
     return storage_factory
@@ -63,7 +55,7 @@ def swh_storage(swh_rpc_client, app_server):
     # journal_writer attribute.
     storage = swh_rpc_client
 
-    journal_writer = getattr(storage, 'journal_writer', None)
+    journal_writer = getattr(storage, "journal_writer", None)
     storage.journal_writer = app_server.storage.journal_writer
     yield storage
     storage.journal_writer = journal_writer
@@ -73,5 +65,5 @@ class TestStorage(_TestStorage):
     def test_content_update(self, swh_storage, app_server):
         # TODO, journal_writer not supported
         swh_storage.journal_writer.journal = None
-        with patch.object(server.storage.journal_writer, 'journal', None):
+        with patch.object(server.storage.journal_writer, "journal", None):
             super().test_content_update(swh_storage)
